@@ -9,23 +9,24 @@
 //
 
 #import "VLCAppDelegate.h"
-#import "DirectoryWatcher.h"
+#import "VLCMediaFileDiscoverer.h"
 #import "NSString+SupportedMedia.h"
 #import "UIDevice+SpeedCategory.h"
 
 #import "VLCPlaylistViewController.h"
-#import "VLCMenuViewController.h"
 #import "VLCMovieViewController.h"
 #import "PAPasscodeViewController.h"
 #import "UINavigationController+Theme.h"
+#import "VLCHTTPUploaderController.h"
+#import "VLCMenuTableViewController.h"
 
-@interface VLCAppDelegate () <PAPasscodeViewControllerDelegate, DirectoryWatcherDelegate> {
+#define PASSCODE_CHECK_INTERVAL 300
+
+@interface VLCAppDelegate () <PAPasscodeViewControllerDelegate, VLCMediaFileDiscovererDelegate> {
     PAPasscodeViewController *_passcodeLockController;
     VLCDropboxTableViewController *_dropboxTableViewController;
-
-    DirectoryWatcher *_directoryWatcher;
-    NSTimer *_addMediaTimer;
-    NSMutableDictionary *_addedFiles;
+    VLCDownloadViewController *_downloadViewController;
+    int _idleCounter;
 }
 
 @property (nonatomic) BOOL passcodeValidated;
@@ -45,24 +46,37 @@
     else
         skipLoopFilterDefaultValue = kVLCSettingSkipLoopFilterNonRef;
 
-    NSDictionary *appDefaults = @{kVLCSettingPasscodeKey : @"", kVLCSettingPasscodeOnKey : @(NO), kVLCSettingContinueAudioInBackgroundKey : @(YES), kVLCSettingStretchAudio : @(NO), kVLCSettingTextEncoding : kVLCSettingTextEncodingDefaultValue, kVLCSettingSkipLoopFilter : skipLoopFilterDefaultValue};
+    NSDictionary *appDefaults = @{kVLCSettingPasscodeKey : @"", kVLCSettingPasscodeOnKey : @(NO), kVLCSettingContinueAudioInBackgroundKey : @(YES), kVLCSettingStretchAudio : @(NO), kVLCSettingTextEncoding : kVLCSettingTextEncodingDefaultValue, kVLCSettingSkipLoopFilter : skipLoopFilterDefaultValue, kVLCSettingSubtitlesFont : kVLCSettingSubtitlesFontDefaultValue, kVLCSettingSubtitlesFontColor : kVLCSettingSubtitlesFontColorDefaultValue, kVLCSettingSubtitlesFontSize : kVLCSettingSubtitlesFontSizeDefaultValue, kVLCSettingDeinterlace : kVLCSettingDeinterlaceDefaultValue};
 
     [defaults registerDefaults:appDefaults];
 }
 
 - (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
 {
+    // Init the HTTP Server
+    self.uploadController = [[VLCHTTPUploaderController alloc] init];
+
+    // enable crash preventer
+    [[MLMediaLibrary sharedMediaLibrary] applicationWillStart];
+
     self.window = [[UIWindow alloc] initWithFrame:[[UIScreen mainScreen] bounds]];
 
     _playlistViewController = [[VLCPlaylistViewController alloc] init];
+    UINavigationController *navCon = [[UINavigationController alloc] initWithRootViewController:_playlistViewController];
+    [navCon loadTheme];
 
-    self.navigationController = [[UINavigationController alloc] initWithRootViewController:_playlistViewController];
-    [self.navigationController loadTheme];
+    _revealController = [[GHRevealViewController alloc] initWithNibName:nil bundle:nil];
+    _revealController.wantsFullScreenLayout = YES;
+    _menuViewController = [[VLCMenuTableViewController alloc] initWithNibName:nil bundle:nil];
+    _revealController.sidebarViewController = _menuViewController;
+    _revealController.contentViewController = navCon;
 
-    self.window.rootViewController = self.navigationController;
+    self.window.rootViewController = self.revealController;
     [self.window makeKeyAndVisible];
 
-    _directoryWatcher = [DirectoryWatcher watchFolderWithPath:[self directoryPath] delegate:self];
+    VLCMediaFileDiscoverer *discoverer = [VLCMediaFileDiscoverer sharedInstance];
+    [discoverer addObserver:self];
+    [discoverer startDiscovering:[self directoryPath]];
 
     [self validatePasscode];
 
@@ -91,7 +105,8 @@
             [self updateMediaList];
         } else {
             NSURL *parsedUrl = [self parseOpenURL:url];
-            [_playlistViewController openMovieFromURL:parsedUrl];
+            [self.menuViewController selectRowAtIndexPath:[NSIndexPath indexPathForRow:0 inSection:0] animated:NO scrollPosition:UITableViewScrollPositionNone];
+            [self.playlistViewController performSelector:@selector(openMovieFromURL:) withObject:parsedUrl afterDelay:kGHRevealSidebarDefaultAnimationDuration];
         }
         return YES;
     }
@@ -125,8 +140,15 @@
     return url;
 }
 
+- (void)applicationWillEnterForeground:(UIApplication *)application
+{
+    [[MLMediaLibrary sharedMediaLibrary] applicationWillStart];
+    [self validatePasscode];
+}
+
 - (void)applicationWillResignActive:(UIApplication *)application
 {
+    self.nextPasscodeCheckDate = [NSDate dateWithTimeIntervalSinceNow:PASSCODE_CHECK_INTERVAL];
     [[MLMediaLibrary sharedMediaLibrary] applicationWillExit];
 }
 
@@ -136,9 +158,9 @@
     [self updateMediaList];
 }
 
-- (void)applicationDidEnterBackground:(UIApplication *)application
+- (void)applicationWillTerminate:(UIApplication *)application
 {
-    [self validatePasscode]; // Lock library when going to background
+    [[NSUserDefaults standardUserDefaults] synchronize];
 }
 
 #pragma mark - properties
@@ -152,82 +174,35 @@
     return _dropboxTableViewController;
 }
 
-#pragma mark - directory watcher delegate
-
-- (void)addFileTimerFired
+- (VLCDownloadViewController *)downloadViewController
 {
-    NSArray *allKeys = [_addedFiles allKeys];
-    NSFileManager *fileManager = [NSFileManager defaultManager];
-    MLMediaLibrary *sharedLibrary = [MLMediaLibrary sharedMediaLibrary];
-    for (NSString *fileURL in allKeys) {
-        if (![fileManager fileExistsAtPath:fileURL])
-            continue;
-
-        NSDictionary *attribs = [fileManager attributesOfItemAtPath:fileURL error:nil];
-
-        NSNumber *prevFetchedSize = [_addedFiles objectForKey:fileURL];
-        NSNumber *updatedSize = [attribs objectForKey:NSFileSize];
-        if (!updatedSize)
-            continue;
-
-        if ([prevFetchedSize compare:updatedSize] == NSOrderedSame) {
-            [_addedFiles removeObjectForKey:fileURL];
-            [sharedLibrary addFilePaths:@[fileURL]];
-
-            /* exclude media files from backup (QA1719) */
-            NSURL *excludeURL = [NSURL fileURLWithPath:fileURL];
-            [excludeURL setResourceValue:@YES forKey:NSURLIsExcludedFromBackupKey error:nil];
-
-            // TODO Should we update media db after adding new files?
-            [sharedLibrary updateMediaDatabase];
-            [_playlistViewController updateViewContents];
-        } else
-            [_addedFiles setObject:updatedSize forKey:fileURL];
+    if (_downloadViewController == nil) {
+        _downloadViewController = [[VLCDownloadViewController alloc] init];
     }
 
-    if (_addedFiles.count == 0) {
-        [_addMediaTimer invalidate];
-        _addMediaTimer = nil;
+    return _downloadViewController;
+}
+
+#pragma mark - media discovering
+
+- (void)mediaFileAdded:(NSString *)fileName loading:(BOOL)isLoading {
+    if (!isLoading) {
+        MLMediaLibrary *sharedLibrary = [MLMediaLibrary sharedMediaLibrary];
+        [sharedLibrary addFilePaths:@[fileName]];
+
+        /* exclude media files from backup (QA1719) */
+        NSURL *excludeURL = [NSURL fileURLWithPath:fileName];
+        [excludeURL setResourceValue:@YES forKey:NSURLIsExcludedFromBackupKey error:nil];
+
+        // TODO Should we update media db after adding new files?
+        [sharedLibrary updateMediaDatabase];
+        [_playlistViewController updateViewContents];
     }
 }
 
-- (void)directoryDidChange:(DirectoryWatcher *)folderWatcher
-{
-    NSArray *foundFiles = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:[self directoryPath] error:nil];
-    NSMutableArray *matchedFiles = [NSMutableArray arrayWithCapacity:foundFiles.count];
-    for (NSString *fileName in foundFiles) {
-        if ([fileName isSupportedMediaFormat])
-            [matchedFiles addObject:[[self directoryPath] stringByAppendingPathComponent:fileName]];
-    }
-
-    NSArray *mediaFiles = [MLFile allFiles];
-    if (mediaFiles.count > matchedFiles.count) { // File was deleted
-        [[MLMediaLibrary sharedMediaLibrary] updateMediaDatabase];
-        [_playlistViewController updateViewContents];
-
-    } else if (mediaFiles.count < matchedFiles.count) { // File was added
-        NSMutableArray *addedFiles = [NSMutableArray array];
-        for (NSString *fileName in matchedFiles) {
-            NSURL *fileURL = [NSURL fileURLWithPath:fileName];
-
-            BOOL found = NO;
-            for (MLFile *mediaFile in mediaFiles) {
-                if ([mediaFile.url isEqualToString:fileURL.absoluteString])
-                    found = YES;
-            }
-
-            if (!found)
-                [addedFiles addObject:fileName];
-        }
-
-        _addedFiles = [NSMutableDictionary dictionaryWithCapacity:[addedFiles count]];
-        for (NSString *fileURL in addedFiles)
-            [_addedFiles setObject:@(0) forKey:fileURL];
-
-        _addMediaTimer = [NSTimer scheduledTimerWithTimeInterval:2. target:self
-                                                        selector:@selector(addFileTimerFired)
-                                                        userInfo:nil repeats:YES];
-    }
+- (void)mediaFileDeleted:(NSString *)name {
+    [[MLMediaLibrary sharedMediaLibrary] updateMediaDatabase];
+    [_playlistViewController updateViewContents];
 }
 
 #pragma mark - media list methods
@@ -252,7 +227,7 @@
     NSMutableArray *filePaths = [NSMutableArray arrayWithCapacity:[foundFiles count]];
     NSURL *fileURL;
     for (NSString *fileName in foundFiles) {
-        if ([fileName isSupportedMediaFormat]) {
+        if ([fileName isSupportedMediaFormat] || [fileName isSupportedAudioMediaFormat]) {
             [filePaths addObject:[directoryPath stringByAppendingPathComponent:fileName]];
 
             /* exclude media files from backup (QA1719) */
@@ -289,8 +264,8 @@
 - (void)PAPasscodeViewControllerDidEnterPasscode:(PAPasscodeViewController *)controller
 {
     // TODO add transition animation, i.e. fade
-    self.nextPasscodeCheckDate = [NSDate dateWithTimeIntervalSinceNow:300];
-    self.window.rootViewController = self.navigationController;
+    self.nextPasscodeCheckDate = [NSDate dateWithTimeIntervalSinceNow:PASSCODE_CHECK_INTERVAL];
+    self.window.rootViewController = self.revealController;
 }
 
 - (void)PAPasscodeViewController:(PAPasscodeViewController *)controller didFailToEnterPasscode:(NSInteger)attempts
@@ -298,4 +273,19 @@
     // TODO handle error attempts
 }
 
+#pragma mark - idle timer preventer
+- (void)disableIdleTimer
+{
+    _idleCounter++;
+    if ([UIApplication sharedApplication].idleTimerDisabled == NO)
+        [UIApplication sharedApplication].idleTimerDisabled = YES;
+}
+
+- (void)activateIdleTimer
+{
+    _idleCounter--;
+    if (_idleCounter < 1)
+        [UIApplication sharedApplication].idleTimerDisabled = NO;
+}
+
 @end
