@@ -8,7 +8,7 @@
 //  Refer to the COPYING file of the official project for license.
 //
 
-#define kVLCVersionCodename @"Aspen"
+#define kVLCVersionCodename @"The Mojo Wire"
 
 #define kVLCSettingPasscodeKey @"Passcode"
 #define kVLCSettingPasscodeOnKey @"PasscodeProtection"
@@ -22,12 +22,22 @@
 #define kVLCSettingSkipLoopFilterNone @(0)
 #define kVLCSettingSkipLoopFilterNonRef @(1)
 #define kVLCSettingSkipLoopFilterNonKey @(3)
+#define kVLCSettingSaveHTTPUploadServerStatus @"isHTTPServerOn"
+#define kVLCSettingSubtitlesFont @"quartztext-font"
+#define kVLCSettingSubtitlesFontDefaultValue @"HelveticaNeue"
+#define kVLCSettingSubtitlesFontSize @"quartztext-rel-fontsize"
+#define kVLCSettingSubtitlesFontSizeDefaultValue @"16"
+#define kVLCSettingSubtitlesFontColor @"quartztext-color"
+#define kVLCSettingSubtitlesFontColorDefaultValue @"16777215"
+#define kVLCSettingDeinterlace @"deinterlace"
+#define kVLCSettingDeinterlaceDefaultValue @"0"
 
 #define kVLCShowRemainingTime @"show-remaining-time"
 #define kVLCRecentURLs @"recent-urls"
 #define kVLCPrivateWebStreaming @"private-streaming"
 
-#define kSupportedFileExtensions @"\\.(3gp|3gp|3gp2|3gpp|amv|asf|avi|axv|divx|dv|flv|f4v|gvi|gxf|m1v|m2p|m2t|m2ts|m2v|m4v|mks|mkv|moov|mov|mp2v|mp4|mpeg|mpeg1|mpeg2|mpeg4|mpg|mpv|mt2s|mts|mxf|nsv|nuv|oga|ogg|ogm|ogv|ogx|spx|ps|qt|rar|rec|rm|rmvb|tod|ts|tts|vob|vro|webm|wm|wmv|wtv|xesc)$"
+#define kSupportedFileExtensions @"\\.(3gp|3gp|3gp2|3gpp|amv|asf|avi|axv|divx|dv|flv|f4v|gvi|gxf|m1v|m2p|m2t|m2ts|m2v|m4v|mks|mkv|moov|mov|mp2v|mp4|mpeg|mpeg1|mpeg2|mpeg4|mpg|mpv|mt2s|mts|mxf|nsv|nuv|oga|ogg|ogm|ogv|ogx|spx|ps|qt|rec|rm|rmvb|tod|ts|tts|vob|vro|webm|wm|wmv|wtv|xesc)$"
 #define kSupportedSubtitleFileExtensions @"\\.(cdg|idx|srt|sub|utf|ass|ssa|aqt|jss|psb|rt|smi|txt|smil)$"
+#define kSupportedAudioFileExtensions @"\\.(aac|aiff|aif|amr|aob|ape|axa|flac|it|m2a|m4a|mka|mlp|mod|mp1|mp2|mp3|mpa|mpc|oga|oma|opus|rmi|s3m|spx|tta|voc|vqf|wav|wma|wv|xa|xm)$"
 
 #define kBlobHash @"521923d214b9ae628da7987cf621e94c4afdd726"
