@@ -23,6 +23,7 @@
     NSString *_currentPath;
 
     UIBarButtonItem *_backButton;
+    UIBarButtonItem *_backToMenuButton;
 
     UIBarButtonItem *_numberOfFilesBarButtonItem;
     UIBarButtonItem *_progressBarButtonItem;
@@ -41,6 +42,8 @@
 {
     [super viewDidLoad];
 
+    self.modalPresentationStyle = UIModalPresentationFormSheet;
+
     _dropboxController = [[VLCDropboxController alloc] init];
     _dropboxController.delegate = self;
 
@@ -52,7 +55,8 @@
     self.navigationItem.titleView.contentMode = UIViewContentModeScaleAspectFit;
 
     _backButton = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(goBack:)];
-    self.navigationItem.leftBarButtonItem = _backButton;
+    _backToMenuButton = [UIBarButtonItem themedRevealMenuButtonWithTarget:self andSelector:@selector(goBack:)];
+    self.navigationItem.leftBarButtonItem = _backToMenuButton;
 
     self.tableView.rowHeight = [VLCDropboxTableViewCell heightOfCell];
     self.tableView.separatorColor = [UIColor colorWithWhite:.122 alpha:1.];
@@ -68,6 +72,8 @@
 
     [_loginToDropboxButton setTitle:NSLocalizedString(@"DROPBOX_LOGIN", @"") forState:UIControlStateNormal];
 
+    [self.navigationController.toolbar setBackgroundImage:[UIImage imageNamed:@"sudHeaderBg"] forToolbarPosition:UIToolbarPositionAny barMetrics:UIBarMetricsDefault];
+
     [self _showProgressInToolbar:NO];
 
     _activityIndicator = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhiteLarge];
@@ -112,8 +118,7 @@
     [_activityIndicator startAnimating];
     [_dropboxController requestDirectoryListingAtPath:_currentPath];
 
-    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad)
-        _backButton.enabled = ![_currentPath isEqualToString:@"/"];
+    self.navigationItem.leftBarButtonItem = ![_currentPath isEqualToString:@"/"] ? _backButton : _backToMenuButton;
 }
 
 #pragma mark - interface interaction
@@ -131,7 +136,7 @@
         _currentPath = [_currentPath stringByDeletingLastPathComponent];
         [self _requestInformationForCurrentPath];
     } else
-        [self.navigationController popViewControllerAnimated:YES];
+        [[(VLCAppDelegate*)[UIApplication sharedApplication].delegate revealController] toggleSidebar:![(VLCAppDelegate*)[UIApplication sharedApplication].delegate revealController].sidebarShowing duration:kGHRevealSidebarDefaultAnimationDuration];
 }
 
 #pragma mark - Table view data source
