@@ -289,26 +289,26 @@
 
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
 
-    _mediaPlayer = nil;
-    _mediaPlayer = [[VLCMediaPlayer alloc] initWithOptions:@[[NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFont, [defaults objectForKey:kVLCSettingSubtitlesFont]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFontColor, [defaults objectForKey:kVLCSettingSubtitlesFontColor]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFontSize, [defaults objectForKey:kVLCSettingSubtitlesFontSize]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingDeinterlace, [defaults objectForKey:kVLCSettingDeinterlace]]]];
-    [_mediaPlayer setDelegate:self];
-    [_mediaPlayer setDrawable:self.movieView];
-
     if (!self.mediaItem && !self.url) {
         [self _stopPlayback];
         return;
     }
 
+    _mediaPlayer = [[VLCMediaPlayer alloc] initWithOptions:@[[NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFont, [defaults objectForKey:kVLCSettingSubtitlesFont]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFontColor, [defaults objectForKey:kVLCSettingSubtitlesFontColor]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFontSize, [defaults objectForKey:kVLCSettingSubtitlesFontSize]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingDeinterlace, [defaults objectForKey:kVLCSettingDeinterlace]]]];
+    [_mediaPlayer setDelegate:self];
+    [_mediaPlayer setDrawable:self.movieView];
+
     VLCMedia *media;
     if (self.mediaItem) {
         self.title = [self.mediaItem title];
-        media = [VLCMedia mediaWithURL:[NSURL URLWithString:self.mediaItem.url]];
-        self.mediaItem.unread = @(NO);
+        MLFile *item = self.mediaItem;
+        media = [VLCMedia mediaWithURL:[NSURL URLWithString:item.url]];
+        item.unread = @(NO);
 
-        if (self.mediaItem.isAlbumTrack) {
-            self.trackNameLabel.text = self.mediaItem.albumTrack.title;
-            self.artistNameLabel.text = self.mediaItem.albumTrack.artist;
-            self.albumNameLabel.text = self.mediaItem.albumTrack.album.name;
+        if (item.isAlbumTrack) {
+            self.trackNameLabel.text = item.albumTrack.title;
+            self.artistNameLabel.text = item.albumTrack.artist;
+            self.albumNameLabel.text = item.albumTrack.album.name;
         } else
             self.trackNameLabel.text = self.artistNameLabel.text = self.albumNameLabel.text = @"";
     } else {
@@ -336,16 +336,9 @@
                     case 1647457633:
                     case 858612577:
                     case 862151027:
-                    case 2126701:
-                    case 544437348:
-                    case 542331972:
-                    case 1651733604:
-                    case 1668510820:
-                    case 1702065252:
-                    case 1752396900:
-                    case 1819505764:
-                    case 18903917:
                     case 862151013:
+                    case 1684566644:
+                    case 2126701:
                     {
                         if (![self _blobCheck]) {
                             [media addOptions:@{@"no-audio" : [NSNull null]}];
@@ -479,9 +472,13 @@
             APLog(@"we weren't an observer yet");
         }
 
-        [_mediaPlayer pause];
-        [self _saveCurrentState];
-        [_mediaPlayer stop];
+        if (_mediaPlayer.media) {
+            [_mediaPlayer pause];
+            [self _saveCurrentState];
+            [_mediaPlayer stop];
+        }
+        if (_mediaPlayer)
+            _mediaPlayer = nil;
     }
     if (_mediaItem)
         _mediaItem = nil;
@@ -492,9 +489,15 @@
 - (void)_saveCurrentState
 {
     if (self.mediaItem) {
-        self.mediaItem.lastPosition = @([_mediaPlayer position]);
-        self.mediaItem.lastAudioTrack = @(_mediaPlayer.currentAudioTrackIndex);
-        self.mediaItem.lastSubtitleTrack = @(_mediaPlayer.currentVideoSubTitleIndex);
+        @try {
+            MLFile *item = self.mediaItem;
+            item.lastPosition = @([_mediaPlayer position]);
+            item.lastAudioTrack = @(_mediaPlayer.currentAudioTrackIndex);
+            item.lastSubtitleTrack = @(_mediaPlayer.currentVideoSubTitleIndex);
+        }
+        @catch (NSException *exception) {
+            APLog(@"failed to save current media state - file removed?");
+        }
     }
 }
 
@@ -1001,8 +1004,6 @@
             _shouldResumePlaying = YES;
         }
     }
-
-    glFinish();
 }
 
 - (void)applicationDidEnterBackground:(NSNotification *)notification
