@@ -17,6 +17,7 @@
 #import "VLCBugreporter.h"
 #import "VLCAppDelegate.h"
 #import "UIBarButtonItem+Theme.h"
+#import "AQGridView.h"
 
 
 #ifndef UIStatusBarStyleLightContent
@@ -28,9 +29,14 @@
 
 @interface VLCPlaylistViewController () <AQGridViewDataSource, AQGridViewDelegate, UITableViewDataSource, UITableViewDelegate, MLMediaLibrary> {
     NSMutableArray *_foundMedia;
-    NSUInteger _libraryMode;
+    VLCLibraryMode _libraryMode;
     UIBarButtonItem *_menuButton;
 }
+
+@property (nonatomic, strong) UITableView *tableView;
+@property (nonatomic, strong) AQGridView *gridView;
+@property (nonatomic, strong) EmptyLibraryView *emptyLibraryView;
+
 @end
 
 @implementation VLCPlaylistViewController
@@ -39,21 +45,28 @@
     if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPhone) {
         _tableView = [[UITableView alloc] initWithFrame:[UIScreen mainScreen].bounds style:UITableViewStylePlain];
         _tableView.backgroundColor = [UIColor colorWithWhite:.122 alpha:1.];
+        _tableView.rowHeight = [VLCPlaylistTableViewCell heightOfCell];
+        _tableView.separatorColor = [UIColor colorWithWhite:.122 alpha:1.];
         _tableView.delegate = self;
         _tableView.dataSource = self;
         self.view = _tableView;
     } else {
         _gridView = [[AQGridView alloc] initWithFrame:[UIScreen mainScreen].bounds];
+        _gridView.separatorStyle = AQGridViewCellSeparatorStyleEmptySpace;
+        _gridView.alwaysBounceVertical = YES;
+        _gridView.indicatorStyle = UIScrollViewIndicatorStyleWhite;
         _gridView.delegate = self;
         _gridView.dataSource = self;
         _gridView.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"libraryBackground"]];
         self.view = _gridView;
     }
 
-    _libraryMode = kVLCLibraryModeAllFiles;
+    _libraryMode = VLCLibraryModeAllFiles;
 
     self.view.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
     self.emptyLibraryView = [[[NSBundle mainBundle] loadNibNamed:@"VLCEmptyLibraryView" owner:self options:nil] lastObject];
+    _emptyLibraryView.emptyLibraryLongDescriptionLabel.lineBreakMode = UILineBreakModeWordWrap;
+    _emptyLibraryView.emptyLibraryLongDescriptionLabel.numberOfLines = 0;
 }
 
 #pragma mark -
@@ -61,7 +74,7 @@
 - (void)viewDidLoad
 {
     [super viewDidLoad];
-
+    self.title = NSLocalizedString(@"LIBRARY_ALL_FILES", @"");
     _menuButton = [UIBarButtonItem themedRevealMenuButtonWithTarget:self andSelector:@selector(leftButtonAction:)];
 
     /* After day 354 of the year, the usual VLC cone is replaced by another cone
@@ -86,19 +99,7 @@
                                        forState:UIControlStateHighlighted barMetrics:UIBarMetricsDefault];
     }
 
-    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
-        _gridView.separatorStyle = AQGridViewCellSeparatorStyleEmptySpace;
-        _gridView.alwaysBounceVertical = YES;
-        _gridView.indicatorStyle = UIScrollViewIndicatorStyleWhite;
-    } else {
-        _tableView.rowHeight = [VLCPlaylistTableViewCell heightOfCell];
-        _tableView.separatorColor = [UIColor colorWithWhite:.122 alpha:1.];
-    }
-    self.title = NSLocalizedString(@"LIBRARY_ALL_FILES", @"");
-
     _emptyLibraryView.emptyLibraryLabel.text = NSLocalizedString(@"EMPTY_LIBRARY", @"");
-    _emptyLibraryView.emptyLibraryLongDescriptionLabel.lineBreakMode = UILineBreakModeWordWrap;
-    _emptyLibraryView.emptyLibraryLongDescriptionLabel.numberOfLines = 0;
     _emptyLibraryView.emptyLibraryLongDescriptionLabel.text = NSLocalizedString(@"EMPTY_LIBRARY_LONG", @"");
     [_emptyLibraryView.emptyLibraryLongDescriptionLabel sizeToFit];
 }
@@ -116,11 +117,11 @@
     if ([[MLMediaLibrary sharedMediaLibrary] libraryNeedsUpgrade]) {
         self.navigationItem.rightBarButtonItem = nil;
         self.navigationItem.leftBarButtonItem = nil;
+        self.title = @"";
         self.emptyLibraryView.emptyLibraryLabel.text = NSLocalizedString(@"UPGRADING_LIBRARY", @"");
         self.emptyLibraryView.emptyLibraryLongDescriptionLabel.hidden = YES;
         [self.emptyLibraryView.activityIndicator startAnimating];
-        self.emptyLibraryView.frame = self.view.frame;
-        self.title = @"";
+        self.emptyLibraryView.frame = self.view.bounds;
         [self.view addSubview:self.emptyLibraryView];
 
         [[MLMediaLibrary sharedMediaLibrary] setDelegate: self];
@@ -153,6 +154,35 @@
         [[VLCBugreporter sharedInstance] handleBugreportRequest];
 }
 
+- (void)openMediaObject:(NSManagedObject *)mediaObject
+{
+    if ([mediaObject isKindOfClass:[MLAlbum class]]) {
+        _foundMedia = [NSMutableArray arrayWithArray:[[(MLAlbum *)mediaObject tracks] allObjects]];
+        self.navigationItem.leftBarButtonItem = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(backToAllItems:)];
+        [self.navigationItem.leftBarButtonItem setTitle:NSLocalizedString(@"LIBRARY_MUSIC", @"")];
+        self.title = [(MLAlbum*)mediaObject name];
+        [self reloadViews];
+    } else if ([mediaObject isKindOfClass:[MLShow class]]) {
+        _foundMedia = [NSMutableArray arrayWithArray:[[(MLShow *)mediaObject episodes] allObjects]];
+        self.navigationItem.leftBarButtonItem = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(backToAllItems:)];
+        [self.navigationItem.leftBarButtonItem setTitle:NSLocalizedString(@"LIBRARY_SERIES", @"")];
+        self.title = [(MLShow*)mediaObject name];
+        [self reloadViews];
+    } else {
+        if (!self.movieViewController)
+            self.movieViewController = [[VLCMovieViewController alloc] initWithNibName:nil bundle:nil];
+
+        if ([mediaObject isKindOfClass:[MLFile class]])
+            self.movieViewController.mediaItem = (MLFile *)mediaObject;
+        else if ([mediaObject isKindOfClass:[MLAlbumTrack class]])
+            self.movieViewController.mediaItem = [(MLAlbumTrack*)mediaObject files].anyObject;
+        else if ([mediaObject isKindOfClass:[MLShowEpisode class]])
+            self.movieViewController.mediaItem = [(MLShowEpisode*)mediaObject files].anyObject;
+
+        [self.navigationController pushViewController:self.movieViewController animated:YES];
+    }
+}
+
 - (void)removeMediaObject:(MLFile *)mediaObject
 {
     NSFileManager *fileManager = [NSFileManager defaultManager];
@@ -181,11 +211,11 @@
     if (self.emptyLibraryView.superview)
         [self.emptyLibraryView removeFromSuperview];
 
-    if (_foundMedia.count <= 0) {
-        self.emptyLibraryView.frame = self.view.frame;
+    if (_foundMedia.count == 0) {
+        self.emptyLibraryView.frame = self.view.bounds;
         [self.view addSubview:self.emptyLibraryView];
     }
-    if (_libraryMode == kVLCLibraryModeAllFiles && _foundMedia.count > 0)
+    if (_libraryMode == VLCLibraryModeAllFiles && _foundMedia.count > 0)
         self.navigationItem.rightBarButtonItem = self.editButtonItem;
     else
         self.navigationItem.rightBarButtonItem = nil;
@@ -198,11 +228,11 @@
 
 - (void)libraryUpgradeComplete
 {
+    self.title = NSLocalizedString(@"LIBRARY_ALL_FILES", @"");
+    self.navigationItem.leftBarButtonItem = _menuButton;
     self.emptyLibraryView.emptyLibraryLongDescriptionLabel.hidden = NO;
     self.emptyLibraryView.emptyLibraryLabel.text = NSLocalizedString(@"EMPTY_LIBRARY", @"");
     [self.emptyLibraryView.activityIndicator stopAnimating];
-    self.title = NSLocalizedString(@"LIBRARY_ALL_FILES", @"");
-    self.navigationItem.leftBarButtonItem = _menuButton;
     [self.emptyLibraryView removeFromSuperview];
 
     [self updateViewContents];
@@ -216,30 +246,21 @@
 
 - (void)updateViewContents
 {
-    if (_libraryMode == kVLCLibraryModeAllAlbums) {
+    if (_libraryMode == VLCLibraryModeAllAlbums) {
         NSArray *rawAlbums = [MLAlbum allAlbums];
         _foundMedia = [[NSMutableArray alloc] init];
-        NSUInteger count = rawAlbums.count;
-        MLAlbum *album;
-
-        for (NSUInteger x = 0; x < count; x++) {
-            album = rawAlbums[x];
+        for (MLAlbum *album in rawAlbums) {
             if (album.name.length > 0 && album.tracks.count > 0)
                 [_foundMedia addObject:album];
         }
-        rawAlbums = nil;
-    } else if (_libraryMode == kVLCLibraryModeAllSeries) {
+
+    } else if (_libraryMode == VLCLibraryModeAllSeries) {
         NSArray *rawShows = [MLShow allShows];
         _foundMedia = [[NSMutableArray alloc] init];
-        NSUInteger count = rawShows.count;
-        MLShow *show;
-
-        for (NSUInteger x = 0; x < count; x++) {
-            show = rawShows[x];
+        for (MLShow *show in rawShows) {
             if (show.name.length > 0 && show.episodes.count > 0)
                 [_foundMedia addObject:show];
         }
-        rawShows = nil;
     } else
         _foundMedia = [NSMutableArray arrayWithArray:[MLFile allFiles]];
 
@@ -250,10 +271,8 @@
 {
     if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPhone)
         [self.tableView reloadData];
-    else {
+    else
         [self.gridView reloadData];
-        [self.gridView performSelector:@selector(reloadData) withObject:nil afterDelay:2.];
-    }
 
     [self _displayEmptyLibraryViewIfNeeded];
 }
@@ -304,33 +323,8 @@
 - (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
 {
     [tableView deselectRowAtIndexPath:indexPath animated:YES];
-
-    NSManagedObject *currentObject = _foundMedia[indexPath.row];
-    if ([currentObject isKindOfClass:[MLAlbum class]]) {
-        _foundMedia = [NSMutableArray arrayWithArray:[[(MLAlbum *)currentObject tracks] allObjects]];
-        self.navigationItem.leftBarButtonItem = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(backToAllItems:)];
-        [self.navigationItem.leftBarButtonItem setTitle:NSLocalizedString(@"LIBRARY_MUSIC", @"")];
-        self.title = [(MLAlbum*)currentObject name];
-        [self reloadViews];
-    } else if ([currentObject isKindOfClass:[MLShow class]]) {
-        _foundMedia = [NSMutableArray arrayWithArray:[[(MLShow *)currentObject episodes] allObjects]];
-        self.navigationItem.leftBarButtonItem = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(backToAllItems:)];
-        [self.navigationItem.leftBarButtonItem setTitle:NSLocalizedString(@"LIBRARY_SERIES", @"")];
-        self.title = [(MLShow*)currentObject name];
-        [self reloadViews];
-    } else {
-        if (!self.movieViewController)
-            self.movieViewController = [[VLCMovieViewController alloc] initWithNibName:nil bundle:nil];
-
-        if ([currentObject isKindOfClass:[MLFile class]])
-            self.movieViewController.mediaItem = (MLFile *)currentObject;
-        else if ([currentObject isKindOfClass:[MLAlbumTrack class]])
-            self.movieViewController.mediaItem = [(MLAlbumTrack*)currentObject files].anyObject;
-        else if ([currentObject isKindOfClass:[MLShowEpisode class]])
-            self.movieViewController.mediaItem = [(MLShowEpisode*)currentObject files].anyObject;
-
-        [self.navigationController pushViewController:self.movieViewController animated:YES];
-    }
+    NSManagedObject *selectedObject = _foundMedia[indexPath.row];
+    [self openMediaObject:selectedObject];
 }
 
 #pragma mark - AQGridView
@@ -363,33 +357,8 @@
 - (void)gridView:(AQGridView *)gridView didSelectItemAtIndex:(NSUInteger)index
 {
     [self.gridView deselectItemAtIndex:index animated:YES];
-
-    NSManagedObject *currentObject = _foundMedia[index];
-    if ([currentObject isKindOfClass:[MLAlbum class]]) {
-        _foundMedia = [NSMutableArray arrayWithArray:[[(MLAlbum *)currentObject tracks] allObjects]];
-        self.navigationItem.leftBarButtonItem = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(backToAllItems:)];
-        [self.navigationItem.leftBarButtonItem setTitle:NSLocalizedString(@"LIBRARY_MUSIC", @"")];
-        self.title = [(MLAlbum*)currentObject name];
-        [self reloadViews];
-    } else if ([currentObject isKindOfClass:[MLShow class]]) {
-        _foundMedia = [NSMutableArray arrayWithArray:[[(MLShow *)currentObject episodes] allObjects]];
-        self.navigationItem.leftBarButtonItem = [UIBarButtonItem themedBackButtonWithTarget:self andSelector:@selector(backToAllItems:)];
-        [self.navigationItem.leftBarButtonItem setTitle:NSLocalizedString(@"LIBRARY_SERIES", @"")];
-        self.title = [(MLShow*)currentObject name];
-        [self reloadViews];
-    } else {
-        if (!self.movieViewController)
-            self.movieViewController = [[VLCMovieViewController alloc] initWithNibName:nil bundle:nil];
-
-        if ([currentObject isKindOfClass:[MLFile class]])
-            self.movieViewController.mediaItem = (MLFile *)currentObject;
-        else if ([currentObject isKindOfClass:[MLAlbumTrack class]])
-            self.movieViewController.mediaItem = [(MLAlbumTrack*)currentObject files].anyObject;
-        else if ([currentObject isKindOfClass:[MLShowEpisode class]])
-            self.movieViewController.mediaItem = [(MLShowEpisode*)currentObject files].anyObject;
-
-        [self.navigationController pushViewController:self.movieViewController animated:YES];
-    }
+    NSManagedObject *selectedObject = _foundMedia[index];
+    [self openMediaObject:selectedObject];
 }
 
 - (void)gridView:(AQGridView *)aGridView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndex:(NSUInteger)index
@@ -401,7 +370,7 @@
 #pragma mark - UI implementation
 - (void)setEditing:(BOOL)editing animated:(BOOL)animated
 {
-    if (_libraryMode != kVLCLibraryModeAllFiles)
+    if (_libraryMode != VLCLibraryModeAllFiles)
         return;
 
     [super setEditing:editing animated:animated];
@@ -427,7 +396,7 @@
 
 - (UITableViewCellEditingStyle)tableView:(UITableView *)aTableView editingStyleForRowAtIndexPath:(NSIndexPath *)indexPath
 {
-    if (_libraryMode != kVLCLibraryModeAllFiles)
+    if (_libraryMode != VLCLibraryModeAllFiles)
         return UITableViewCellEditingStyleNone;
 
     return UITableViewCellEditingStyleDelete;
@@ -444,6 +413,34 @@
     [self setLibraryMode:_libraryMode];
 }
 
+#pragma mark - coin coin
+
+- (void)openMovieFromURL:(NSURL *)url
+{
+    if (!self.movieViewController)
+        self.movieViewController = [[VLCMovieViewController alloc] initWithNibName:nil bundle:nil];
+
+    if (self.navigationController.topViewController != self.movieViewController)
+        [self.navigationController pushViewController:self.movieViewController animated:YES];
+
+    self.movieViewController.url = url;
+}
+
+- (void)setLibraryMode:(VLCLibraryMode)mode
+{
+    _libraryMode = mode;
+
+    if (_libraryMode == VLCLibraryModeAllAlbums)
+        self.title = NSLocalizedString(@"LIBRARY_MUSIC", @"");
+    else if( _libraryMode == VLCLibraryModeAllSeries)
+        self.title = NSLocalizedString(@"LIBRARY_SERIES", @"");
+    else
+        self.title = NSLocalizedString(@"LIBRARY_ALL_FILES", @"");
+
+    [self updateViewContents];
+}
+
+#pragma mark - autorotation
 /* deprecated in iOS 6 */
 - (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation
 {
@@ -461,7 +458,7 @@
         return UIInterfaceOrientationMaskAll;
 
     return (_foundMedia.count > 0)? UIInterfaceOrientationMaskAllButUpsideDown:
-                                    UIInterfaceOrientationMaskPortrait;
+    UIInterfaceOrientationMaskPortrait;
 }
 
 /* introduced in iOS 6 */
@@ -469,31 +466,4 @@
     return (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) || (_foundMedia.count > 0);
 }
 
-#pragma mark - coin coin
-
-- (void)openMovieFromURL:(NSURL *)url
-{
-    if (!self.movieViewController)
-        self.movieViewController = [[VLCMovieViewController alloc] initWithNibName:nil bundle:nil];
-
-    if (self.navigationController.topViewController != self.movieViewController)
-        [self.navigationController pushViewController:self.movieViewController animated:YES];
-
-    self.movieViewController.url = url;
-}
-
-- (void)setLibraryMode:(NSUInteger)mode
-{
-    _libraryMode = mode;
-
-    if (_libraryMode == kVLCLibraryModeAllAlbums)
-        self.title = NSLocalizedString(@"LIBRARY_MUSIC", @"");
-    else if( _libraryMode == kVLCLibraryModeAllSeries)
-        self.title = NSLocalizedString(@"LIBRARY_SERIES", @"");
-    else
-        self.title = NSLocalizedString(@"LIBRARY_ALL_FILES", @"");
-
-    [self updateViewContents];
-}
-
 @end
