@@ -4,14 +4,14 @@
 
 set -e
 
-PLATFORM=OS
-SDK=iphoneos6.1
+PLATFORM=iphoneos
+SDK=6.1
 SDK_MIN=5.1
 VERBOSE=no
 CONFIGURATION="Release"
-TESTEDHASH=12c62370e
-TESTEDVLCKITHASH=9032a525e
-TESTEDMEDIALIBRARYKITHASH=9eae8ee41
+TESTEDHASH=c891dc7d3
+TESTEDVLCKITHASH=eda8237e6
+TESTEDMEDIALIBRARYKITHASH=82a2f20c8
 
 usage()
 {
@@ -59,7 +59,7 @@ buildxcodeproj()
 
     xcodebuild -project "$1.xcodeproj" \
                -target "$target" \
-               -sdk $SDK \
+               -sdk $PLATFORM$SDK \
                -configuration ${CONFIGURATION} ${extra} \
                IPHONEOS_DEPLOYMENT_TARGET=${SDK_MIN} > ${out}
 }
@@ -75,8 +75,7 @@ do
              VERBOSE=yes
              ;;
          s)
-             PLATFORM=Simulator
-             SDK=iphonesimulator6.1
+             PLATFORM=iphonesimulator
              ;;
          d)  CONFIGURATION="Debug"
              ;;
@@ -143,16 +142,11 @@ fi
 if ! [ -e OBSlider ]; then
 git clone git://github.com/ole/OBSlider.git
 fi
+if ! [ -e DAVKit ]; then
+git clone git://github.com/mattrajca/DAVKit.git
+fi
 if ! [ -e GHSidebarNav ]; then
 git clone git://github.com/gresrun/GHSidebarNav.git
-cd GHSidebarNav
-git am ../../patches/ghsidebarnav/*.patch
-if [ $? -ne 0 ]; then
-git am --abort
-info "Applying the patches failed, aborting git-am"
-exit 1
-fi
-cd ..
 fi
 if ! [ -e upnpx ]; then
 UPNPXVERSION=1.2.4
@@ -201,7 +195,7 @@ fi
 
 info "Setup 'External' folders"
 
-if [ "$PLATFORM" = "Simulator" ]; then
+if [ "$PLATFORM" = "iphonesimulator" ]; then
     xcbuilddir="build/${CONFIGURATION}-iphonesimulator"
 else
     xcbuilddir="build/${CONFIGURATION}-iphoneos"
@@ -235,7 +229,7 @@ args=""
 if [ "$VERBOSE" = "yes" ]; then
     args="${args} -v"
 fi
-if [ "$PLATFORM" = "Simulator" ]; then
+if [ "$PLATFORM" = "iphonesimulator" ]; then
     args="${args} -s"
     ./build.sh ${args} -k "${SDK}"
 else
